==> kubernetes-model-apiextensions-6.8.1-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CustomResourceSubresourcesFluent<A extends CustomResourceSubresourcesFluent<A>> extends BaseFluent<A>{
  public CustomResourceSubresourcesFluent() {
  }
  public CustomResourceSubresourcesFluent(CustomResourceSubresources instance) {
    instance = (instance != null ? instance : new CustomResourceSubresources());

    if (instance != null) {
      this.withScale(instance.getScale());
      this.withStatus(instance.getStatus());
      this.withScale(instance.getScale());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private CustomResourceSubresourceScaleBuilder scale;
  private CustomResourceSubresourceStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public CustomResourceSubresourceScale buildScale() {
    return this.scale!=null ?this.scale.build():null;
  }
  public A withScale(CustomResourceSubresourceScale scale) {
    _visitables.get("scale").remove(this.scale);
    if (scale!=null){ this.scale= new CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} else { this.scale = null; _visitables.get("scale").remove(this.scale); } return (A) this;
  }
  public boolean hasScale() {
    return this.scale != null;
  }
  public A withNewScale(String labelSelectorPath,String specReplicasPath,String statusReplicasPath) {
    return (A)withScale(new CustomResourceSubresourceScale(labelSelectorPath, specReplicasPath, statusReplicasPath));
  }
  public ScaleNested<A> withNewScale() {
    return new ScaleNested(null);
  }
  public ScaleNested<A> withNewScaleLike(CustomResourceSubresourceScale item) {
    return new ScaleNested(item);
  }
  public ScaleNested<A> editScale() {
    return withNewScaleLike(java.util.Optional.ofNullable(buildScale()).orElse(null));
  }
  public ScaleNested<A> editOrNewScale() {
    return withNewScaleLike(java.util.Optional.ofNullable(buildScale()).orElse(new CustomResourceSubresourceScaleBuilder().build()));
  }
  public ScaleNested<A> editOrNewScaleLike(CustomResourceSubresourceScale item) {
    return withNewScaleLike(java.util.Optional.ofNullable(buildScale()).orElse(item));
  }
  public CustomResourceSubresourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(CustomResourceSubresourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CustomResourceSubresourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public boolean hasStatus() {
    return this.status != null;
  }
  public StatusNested<A> withNewStatus() {
    return new StatusNested(null);
  }
  public StatusNested<A> withNewStatusLike(CustomResourceSubresourceStatus item) {
    return new StatusNested(item);
  }
  public StatusNested<A> editStatus() {
    return withNewStatusLike(java.util.Optional.ofNullable(buildStatus()).orElse(null));
  }
  public StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(java.util.Optional.ofNullable(buildStatus()).orElse(new CustomResourceSubresourceStatusBuilder().build()));
  }
  public StatusNested<A> editOrNewStatusLike(CustomResourceSubresourceStatus item) {
    return withNewStatusLike(java.util.Optional.ofNullable(buildStatus()).orElse(item));
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourcesFluent that = (CustomResourceSubresourcesFluent) o;
    if (!java.util.Objects.equals(scale, that.scale)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(scale,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scale != null) { sb.append("scale:"); sb.append(scale + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ScaleNested<N> extends CustomResourceSubresourceScaleFluent<ScaleNested<N>> implements Nested<N>{
    ScaleNested(CustomResourceSubresourceScale item) {
      this.builder = new CustomResourceSubresourceScaleBuilder(this, item);
    }
    CustomResourceSubresourceScaleBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluent.this.withScale(builder.build());
    }
    public N endScale() {
      return and();
    }
    
  }
  public class StatusNested<N> extends CustomResourceSubresourceStatusFluent<StatusNested<N>> implements Nested<N>{
    StatusNested(CustomResourceSubresourceStatus item) {
      this.builder = new CustomResourceSubresourceStatusBuilder(this, item);
    }
    CustomResourceSubresourceStatusBuilder builder;
    public N and() {
      return (N) CustomResourceSubresourcesFluent.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apiextensions-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/apiextensions/v1/CustomResourceSubresourcesFluent.java <==
package io.fabric8.kubernetes.api.model.apiextensions.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class CustomResourceSubresourcesFluent<A extends CustomResourceSubresourcesFluent<A>> extends BaseFluent<A>{
  public CustomResourceSubresourcesFluent() {
  }
  
  public CustomResourceSubresourcesFluent(CustomResourceSubresources instance) {
    this.copyInstance(instance);
  }
  private CustomResourceSubresourceScaleBuilder scale;
  private CustomResourceSubresourceStatusBuilder status;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(CustomResourceSubresources instance) {
    instance = (instance != null ? instance : new CustomResourceSubresources());
  
    if (instance != null) {
        this.withScale(instance.getScale());
        this.withStatus(instance.getStatus());
        this.withScale(instance.getScale());
        this.withStatus(instance.getStatus());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public CustomResourceSubresourceScale buildScale() {
    return this.scale!=null ?this.scale.build():null;
  }
  
  public A withScale(CustomResourceSubresourceScale scale) {
    _visitables.get("scale").remove(this.scale);
    if (scale!=null){ this.scale= new CustomResourceSubresourceScaleBuilder(scale); _visitables.get("scale").add(this.scale);} else { this.scale = null; _visitables.get("scale").remove(this.scale); } return (A) this;
  }
  
  public boolean hasScale() {
    return this.scale != null;
  }
  
  public A withNewScale(String labelSelectorPath,String specReplicasPath,String statusReplicasPath) {
    return (A)withScale(new CustomResourceSubresourceScale(labelSelectorPath, specReplicasPath, statusReplicasPath));
  }
  
  public ScaleNested<A> withNewScale() {
    return new ScaleNested(null);
  }
  
  public ScaleNested<A> withNewScaleLike(CustomResourceSubresourceScale item) {
    return new ScaleNested(item);
  }
  
  public ScaleNested<A> editScale() {
    return withNewScaleLike(java.util.Optional.ofNullable(buildScale()).orElse(null));
  }
  
  public ScaleNested<A> editOrNewScale() {
    return withNewScaleLike(java.util.Optional.ofNullable(buildScale()).orElse(new CustomResourceSubresourceScaleBuilder().build()));
  }
  
  public ScaleNested<A> editOrNewScaleLike(CustomResourceSubresourceScale item) {
    return withNewScaleLike(java.util.Optional.ofNullable(buildScale()).orElse(item));
  }
  
  public CustomResourceSubresourceStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  
  public A withStatus(CustomResourceSubresourceStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new CustomResourceSubresourceStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  
  public boolean hasStatus() {
    return this.status != null;
  }
  
  public StatusNested<A> withNewStatus() {
    return new StatusNested(null);
  }
  
  public StatusNested<A> withNewStatusLike(CustomResourceSubresourceStatus item) {
    return new StatusNested(item);
  }
  
  public StatusNested<A> editStatus() {
    return withNewStatusLike(java.util.Optional.ofNullable(buildStatus()).orElse(null));
  }
  
  public StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(java.util.Optional.ofNullable(buildStatus()).orElse(new CustomResourceSubresourceStatusBuilder().build()));
  }
  
  public StatusNested<A> editOrNewStatusLike(CustomResourceSubresourceStatus item) {
    return withNewStatusLike(java.util.Optional.ofNullable(buildStatus()).orElse(item));
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CustomResourceSubresourcesFluent that = (CustomResourceSubresourcesFluent) o;
    if (!java.util.Objects.equals(scale, that.scale)) return false;
  
    if (!java.util.Objects.equals(status, that.status)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(scale,  status,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (scale != null) { sb.append("scale:"); sb.append(scale + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class ScaleNested<N> extends CustomResourceSubresourceScaleFluent<ScaleNested<N>> implements Nested<N>{
    ScaleNested(CustomResourceSubresourceScale item) {
      this.builder = new CustomResourceSubresourceScaleBuilder(this, item);
    }
    CustomResourceSubresourceScaleBuilder builder;
    
    public N and() {
      return (N) CustomResourceSubresourcesFluent.this.withScale(builder.build());
    }
    
    public N endScale() {
      return and();
    }
    
  
  }
  public class StatusNested<N> extends CustomResourceSubresourceStatusFluent<StatusNested<N>> implements Nested<N>{
    StatusNested(CustomResourceSubresourceStatus item) {
      this.builder = new CustomResourceSubresourceStatusBuilder(this, item);
    }
    CustomResourceSubresourceStatusBuilder builder;
    
    public N and() {
      return (N) CustomResourceSubresourcesFluent.this.withStatus(builder.build());
    }
    
    public N endStatus() {
      return and();
    }
    
  
  }

}
